Index

A B C D E F G I M O P R S T U V W 
All Classes and Interfaces|All Packages|Constant Field Values

A

AbstractBuilder<T extends AbstractDatastarEvent> - Class in starfederation.datastar.events
 
AbstractBuilder() - Constructor for class starfederation.datastar.events.AbstractBuilder
 
AbstractDatastarEvent - Class in starfederation.datastar.events
 
AbstractDatastarEvent(EventType, List<String>) - Constructor for class starfederation.datastar.events.AbstractDatastarEvent
 
AbstractRequestAdapter - Class in starfederation.datastar.adapters.request
 
AbstractRequestAdapter() - Constructor for class starfederation.datastar.adapters.request.AbstractRequestAdapter
 
AbstractResponseAdapter - Class in starfederation.datastar.adapters.response
 
AbstractResponseAdapter() - Constructor for class starfederation.datastar.adapters.response.AbstractResponseAdapter
 
After - Enum constant in enum class starfederation.datastar.enums.ElementPatchMode
 
Append - Enum constant in enum class starfederation.datastar.enums.ElementPatchMode
 
attributes(String) - Method in class starfederation.datastar.events.ExecuteScript.Builder
 
autoRemove(boolean) - Method in class starfederation.datastar.events.ExecuteScript.Builder
 

B

Before - Enum constant in enum class starfederation.datastar.enums.ElementPatchMode
 
build() - Method in class starfederation.datastar.events.ExecuteScript.Builder
 
build() - Method in class starfederation.datastar.events.PatchElements.Builder
 
build() - Method in class starfederation.datastar.events.PatchSignals.Builder
 
builder() - Static method in class starfederation.datastar.events.ExecuteScript
 
builder() - Static method in class starfederation.datastar.events.PatchElements
 
builder() - Static method in class starfederation.datastar.events.PatchSignals
 
Builder() - Constructor for class starfederation.datastar.events.PatchSignals.Builder
 

C

close() - Method in class starfederation.datastar.utils.ServerSentEventGenerator
Closes the writer when finished.
Consts - Class in starfederation.datastar
This is auto-generated by Datastar.
Consts() - Constructor for class starfederation.datastar.Consts
 
CustomEvent - Class in starfederation.datastar.events
 
CustomEvent(EventType, List<String>) - Constructor for class starfederation.datastar.events.CustomEvent
 

D

data(String) - Method in class starfederation.datastar.events.PatchElements.Builder
 
data(String) - Method in class starfederation.datastar.events.PatchSignals.Builder
 
DATASTAR_KEY - Static variable in class starfederation.datastar.Consts
 
DataStore - Class in starfederation.datastar.utils
A simple data store for managing key-value pairs with serialization/deserialization support.
DataStore() - Constructor for class starfederation.datastar.utils.DataStore
 
DEFAULT_ELEMENT_PATCH_MODE - Static variable in class starfederation.datastar.Consts
 
DEFAULT_ELEMENTS_USE_VIEW_TRANSITIONS - Static variable in class starfederation.datastar.Consts
 
DEFAULT_PATCH_SIGNALS_ONLY_IF_MISSING - Static variable in class starfederation.datastar.Consts
 
DEFAULT_SSE_RETRY_DURATION - Static variable in class starfederation.datastar.Consts
 

E

ElementPatchMode - Enum Class in starfederation.datastar.enums
This is auto-generated by Datastar.
ELEMENTS_DATALINE_LITERAL - Static variable in class starfederation.datastar.Consts
 
EventType - Enum Class in starfederation.datastar.enums
This is auto-generated by Datastar.
ExecuteScript - Class in starfederation.datastar.events
 
ExecuteScript.Builder - Class in starfederation.datastar.events
 

F

fromJson(String) - Method in class starfederation.datastar.utils.DataStore
Deserializes the given JSON string into the store.

G

get(String, Class<T>) - Method in class starfederation.datastar.utils.DataStore
Retrieves the value associated with the given key, cast to the specified type.
getDataLines() - Method in class starfederation.datastar.events.AbstractDatastarEvent
 
getEventType() - Method in class starfederation.datastar.events.CustomEvent
Returns the event type.
getEventType() - Method in class starfederation.datastar.events.ExecuteScript
 
getEventType() - Method in class starfederation.datastar.events.PatchElements
 
getEventType() - Method in class starfederation.datastar.events.PatchSignals
 
getMethod() - Method in interface starfederation.datastar.adapters.request.RequestAdapter
Gets the HTTP method (e.g., GET, POST) of the request.
getParameter(String) - Method in interface starfederation.datastar.adapters.request.RequestAdapter
Retrieves a query parameter by name.
getReader() - Method in class starfederation.datastar.adapters.request.AbstractRequestAdapter
 
getReader() - Method in interface starfederation.datastar.adapters.request.RequestAdapter
Retrieves a BufferedReader to read the request body.
getStore() - Method in class starfederation.datastar.utils.DataStore
Gets the underlying ConcurrentMap store.
getWriter() - Method in class starfederation.datastar.adapters.response.AbstractResponseAdapter
 
getWriter() - Method in interface starfederation.datastar.adapters.response.ResponseAdapter
Provides a `PrintWriter` for writing content to the response.

I

Inner - Enum constant in enum class starfederation.datastar.enums.ElementPatchMode
 

M

mode(ElementPatchMode) - Method in class starfederation.datastar.events.PatchElements.Builder
 
MODE_DATALINE_LITERAL - Static variable in class starfederation.datastar.Consts
 

O

ONLY_IF_MISSING_DATALINE_LITERAL - Static variable in class starfederation.datastar.Consts
 
onlyIfMissing(boolean) - Method in class starfederation.datastar.events.PatchSignals.Builder
 
Outer - Enum constant in enum class starfederation.datastar.enums.ElementPatchMode
 

P

PatchElements - Class in starfederation.datastar.events
 
PatchElements - Enum constant in enum class starfederation.datastar.enums.EventType
 
PatchElements.Builder - Class in starfederation.datastar.events
 
PatchSignals - Class in starfederation.datastar.events
 
PatchSignals - Enum constant in enum class starfederation.datastar.enums.EventType
 
PatchSignals.Builder - Class in starfederation.datastar.events
 
Prepend - Enum constant in enum class starfederation.datastar.enums.ElementPatchMode
 
put(String, Object) - Method in class starfederation.datastar.utils.DataStore
Adds a key-value pair to the store.
putAll(Map<String, Object>) - Method in class starfederation.datastar.utils.DataStore
Adds all entries from the given map to the store.

R

reader - Variable in class starfederation.datastar.adapters.request.AbstractRequestAdapter
 
readSignals(RequestAdapter, ConcurrentMap<String, Object>) - Static method in class starfederation.datastar.utils.SignalReader
Parses incoming data from the browser and unmarshals it into the given store object.
Remove - Enum constant in enum class starfederation.datastar.enums.ElementPatchMode
 
Replace - Enum constant in enum class starfederation.datastar.enums.ElementPatchMode
 
RequestAdapter - Interface in starfederation.datastar.adapters.request
 
ResponseAdapter - Interface in starfederation.datastar.adapters.response
 

S

script(String) - Method in class starfederation.datastar.events.ExecuteScript.Builder
JavaScript to execute on the client.
selector(String) - Method in class starfederation.datastar.events.PatchElements.Builder
 
SELECTOR_DATALINE_LITERAL - Static variable in class starfederation.datastar.Consts
 
send(AbstractDatastarEvent) - Method in class starfederation.datastar.utils.ServerSentEventGenerator
Sends a Datastar event to the client with a monotonically increasing long ID and default retry duration.
send(AbstractDatastarEvent, int) - Method in class starfederation.datastar.utils.ServerSentEventGenerator
Sends a Datastar event to the client with a monotonically increasing long ID and specified retry duration.
send(AbstractDatastarEvent, String) - Method in class starfederation.datastar.utils.ServerSentEventGenerator
Sends a Datastar event to the client with a specified ID and default retry duration.
send(AbstractDatastarEvent, String, int) - Method in class starfederation.datastar.utils.ServerSentEventGenerator
Sends a Datastar event to the client.
ServerSentEventGenerator - Class in starfederation.datastar.utils
 
ServerSentEventGenerator(AbstractResponseAdapter) - Constructor for class starfederation.datastar.utils.ServerSentEventGenerator
Initializes the Server-Sent Event generator.
setCharacterEncoding(String) - Method in class starfederation.datastar.adapters.response.AbstractResponseAdapter
 
setCharacterEncoding(String) - Method in interface starfederation.datastar.adapters.response.ResponseAdapter
Sets the character encoding for the response.
setContentType(String) - Method in class starfederation.datastar.adapters.response.AbstractResponseAdapter
 
setContentType(String) - Method in interface starfederation.datastar.adapters.response.ResponseAdapter
Sets the content type of the response.
setHeader(String, String) - Method in class starfederation.datastar.adapters.response.AbstractResponseAdapter
 
setHeader(String, String) - Method in interface starfederation.datastar.adapters.response.ResponseAdapter
Sets a header on the response.
setStatus(int) - Method in class starfederation.datastar.adapters.response.AbstractResponseAdapter
 
setStatus(int) - Method in interface starfederation.datastar.adapters.response.ResponseAdapter
Sets the HTTP status code for the response.
SignalReader - Class in starfederation.datastar.utils
 
SignalReader() - Constructor for class starfederation.datastar.utils.SignalReader
 
SIGNALS_DATALINE_LITERAL - Static variable in class starfederation.datastar.Consts
 
starfederation.datastar - package starfederation.datastar
 
starfederation.datastar.adapters.request - package starfederation.datastar.adapters.request
 
starfederation.datastar.adapters.response - package starfederation.datastar.adapters.response
 
starfederation.datastar.enums - package starfederation.datastar.enums
 
starfederation.datastar.events - package starfederation.datastar.events
 
starfederation.datastar.utils - package starfederation.datastar.utils
 

T

toJson() - Method in class starfederation.datastar.utils.DataStore
Serializes the store to a JSON string.
toString() - Method in enum class starfederation.datastar.enums.ElementPatchMode
 
toString() - Method in enum class starfederation.datastar.enums.EventType
 
toString() - Method in class starfederation.datastar.events.AbstractDatastarEvent
 
toString() - Method in class starfederation.datastar.utils.DataStore
 

U

USE_VIEW_TRANSITION_DATALINE_LITERAL - Static variable in class starfederation.datastar.Consts
 
useViewTransition(boolean) - Method in class starfederation.datastar.events.PatchElements.Builder
 

V

valueOf(String) - Static method in enum class starfederation.datastar.enums.ElementPatchMode
Returns the enum constant of this class with the specified name.
valueOf(String) - Static method in enum class starfederation.datastar.enums.EventType
Returns the enum constant of this class with the specified name.
values() - Static method in enum class starfederation.datastar.enums.ElementPatchMode
Returns an array containing the constants of this enum class, in the order they are declared.
values() - Static method in enum class starfederation.datastar.enums.EventType
Returns an array containing the constants of this enum class, in the order they are declared.
VERSION - Static variable in class starfederation.datastar.Consts
 

W

writer - Variable in class starfederation.datastar.adapters.response.AbstractResponseAdapter
 
A B C D E F G I M O P R S T U V W 
All Classes and Interfaces|All Packages|Constant Field Values