Package starfederation.datastar.utils
Class SignalReader
java.lang.Object
starfederation.datastar.utils.SignalReader
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic voidreadSignals(RequestAdapter requestAdapter, ConcurrentMap<String, Object> store) Parses incoming data from the browser and unmarshals it into the given store object.
-
Constructor Details
-
SignalReader
public SignalReader()
-
-
Method Details
-
readSignals
public static void readSignals(RequestAdapter requestAdapter, ConcurrentMap<String, Object> store) throws IOExceptionParses incoming data from the browser and unmarshals it into the given store object.- Parameters:
requestAdapter- The request adapter wrapping the incoming request.store- A Map that will hold the parsed data.- Throws:
IOException- If an error occurs during reading or parsing.
-